/* diversity-connman-backend.c -
 *
 * Copyright 2008 Openmoko, Inc.
 * Authored by Chia-I Wu <olv@openmoko.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <diversity-module.h>
#include <diversity-world.h>
#include "diversity-conn-nm.h"

static struct {
	DiversityWorld *world;
	DiversityConnNm *cnm;
} connman;

static void connman_fini(void)
{
	if (connman.cnm) {
		g_object_unref(G_OBJECT(connman.cnm));
		connman.cnm = NULL;
	}

	if (connman.world) {
		g_object_unref(G_OBJECT(connman.world));
		connman.world = NULL;
	}
}

static gint connman_init(DiversityWorld *world, GError **error)
{
	DiversityBard *self;

	connman.world = world;
	g_object_ref(world);

	connman.cnm = diversity_conn_nm_new(world, error);
	if (!connman.cnm) {
		connman_fini();

		g_warning("failed to connect to Connman: %s",
				(*error)->message);
		g_error_free(*error);
		*error = NULL;

		/* don't fail the daemon */
		return TRUE;
	}

	diversity_world_net_set(connman.world,
			DIVERSITY_NET(connman.cnm));

	self = diversity_world_get_self(connman.world);
	diversity_bard_add_equipment(self,
			DIVERSITY_EQUIPMENT(connman.cnm));

	return TRUE;
}

DiversityModuleHandle _diversity_module_handle_connman = {
	.version = DIVERSITY_MODULE_HANDLE_VERSION,
	.name = "Connman",

	.init = connman_init,
	.fini = connman_fini,
};
