/* control-bard.c -
 *
 * Copyright 2007 Openmoko, Inc.
 * Authored by Chia-I Wu <olv@openmoko.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <diversity-bard.h>
#include "diversity-control.h"

static gboolean control_bard_get_equipment(DiversityBard *bard, const gchar *IN_name, gchar **OUT_equipment, GError **error);
#include "control-bard-glue.h"

static gboolean control_bard_get_equipment(DiversityBard *bard, const gchar *IN_name, gchar **OUT_equipment, GError **error)
{
	DiversityEquipment *eqp;
	DiversityControl *ctrl;
	DiversityControlExport *export;

	eqp = diversity_bard_get_equipment_by_name(bard, IN_name);
	if (!eqp) {
		g_set_error(error, DIVERSITY_CONTROL_ERROR, 0,
				"failed to get %s: no such equipment",
				IN_name);

		return FALSE;
	}
	if (!diversity_equipment_get_equipper(eqp)) {
		g_set_error(error, DIVERSITY_CONTROL_ERROR, 0,
				"failed to get %s: equipment is not equipped",
				IN_name);

		return FALSE;
	}

       	ctrl = diversity_control_from_object(DIVERSITY_OBJECT(bard));
	export = diversity_control_object_export(ctrl,
			DIVERSITY_OBJECT(bard), NULL);

	*OUT_equipment =
		g_strdup_printf("%s/equipments/%s",
			export->path,
			diversity_equipment_get_name(eqp));

	return TRUE;
}
