/* diversity-dhcp.h - DiversityDhcp
 *
 * Copyright 2008 Openmoko, Inc.
 * Authored by Chia-I Wu <olv@openmoko.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _DIVERSITY_DHCP_H_
#define _DIVERSITY_DHCP_H_

#define G_DISABLE_CAST_CHECKS

#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS

#define DIVERSITY_TYPE_DHCP		(diversity_dhcp_get_type())
#define DIVERSITY_DHCP(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), DIVERSITY_TYPE_DHCP, DiversityDhcp))
#define DIVERSITY_DHCP_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), DIVERSITY_TYPE_DHCP, DiversityDhcpClass))
#define DIVERSITY_IS_DHCP(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), DIVERSITY_TYPE_DHCP))
#define DIVERSITY_IS_DHCP_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), DIVERSITY_TYPE_DHCP))
#define DIVERSITY_DHCP_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), DIVERSITY_TYPE_DHCP, DiversityDhcpClass))

typedef enum _DiversityDhcpState DiversityDhcpState;

enum _DiversityDhcpState {
	DIVERSITY_DHCP_STATE_INIT,
	DIVERSITY_DHCP_STATE_SELECTING,
	DIVERSITY_DHCP_STATE_REQUESTING,
	DIVERSITY_DHCP_STATE_BOUND,
	DIVERSITY_DHCP_STATE_RENEWING,
	DIVERSITY_DHCP_STATE_REBINDING,
	DIVERSITY_DHCP_STATE_INIT_REBOOT,
	DIVERSITY_DHCP_STATE_REBOOTING,

	DIVERSITY_DHCP_STATE_SLEEP,
	DIVERSITY_DHCP_STATE_CONFIGURED,
};

typedef struct _DiversityDhcp DiversityDhcp;
typedef struct _DiversityDhcpClass DiversityDhcpClass;

struct _DiversityDhcp {
	GObject parent_object;
};

struct _DiversityDhcpClass {
	GObjectClass parent_class;

	void (*state_changed)(DiversityDhcp *dhcpc, DiversityDhcpState state, gpointer user_data);
};

GType diversity_dhcp_get_type(void) G_GNUC_CONST;

DiversityDhcp *diversity_dhcp_new(const gchar *cmdline);
DiversityDhcpState diversity_dhcp_get_state(DiversityDhcp *dhcpc);

gboolean diversity_dhcp_wakeup(DiversityDhcp *dhcpc, GError **error);
void diversity_dhcp_sleep(DiversityDhcp *dhcpc);

G_END_DECLS

#endif /* _DIVERSITY_DHCP_H_ */
