/* diversity-module.h - DiversityModule
 *
 * Copyright 2008 Openmoko, Inc.
 * Authored by Chia-I Wu <olv@openmoko.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _DIVERSITY_MODULE_H_
#define _DIVERSITY_MODULE_H_

#define G_DISABLE_CAST_CHECKS

#include <glib.h>
#include <glib-object.h>
#include <diversity-equipment.h>
#include <diversity-world.h>

G_BEGIN_DECLS

#define DIVERSITY_MODULE_HANDLE_VERSION 0
#define DIVERSITY_MODULE_HANDLE_SYMBOL_NAME "diversity_module_handle"
typedef struct _DiversityModuleHandle DiversityModuleHandle;

struct _DiversityModuleHandle {
	gint version;
	const char *name;

	gint (*init)(DiversityWorld *world, GError **error);
	void (*fini)(void);
};

#define DIVERSITY_TYPE_MODULE			(diversity_module_get_type())
#define DIVERSITY_MODULE(obj)			(G_TYPE_CHECK_INSTANCE_CAST((obj), DIVERSITY_TYPE_MODULE, DiversityModule))
#define DIVERSITY_MODULE_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), DIVERSITY_TYPE_MODULE, DiversityModuleClass))
#define DIVERSITY_IS_MODULE(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), DIVERSITY_TYPE_MODULE))
#define DIVERSITY_IS_MODULE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), DIVERSITY_TYPE_MODULE))
#define DIVERSITY_MODULE_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS((obj), DIVERSITY_TYPE_MODULE, DiversityModuleClass))

typedef struct _DiversityModule DiversityModule;
typedef struct _DiversityModuleClass DiversityModuleClass;

struct _DiversityModule {
	GObject parent_object;
};

struct _DiversityModuleClass {
	GObjectClass parent_class;
};

GType diversity_module_get_type(void) G_GNUC_CONST;

DiversityModule *diversity_module_new(const char *path, GError **error);
DiversityModule *diversity_module_new_from_handle(DiversityModuleHandle *handle);

gboolean diversity_module_is_builtin(DiversityModule *mod);
DiversityModuleHandle *diversity_module_get_handle(DiversityModule *mod);

#endif /* _DIVERSITY_MODULE_H_ */
